@@ -59,6 +59,11 @@ class Settings(BaseSettings):  # pylint:disable=too-few-public-methods
     max_width: int = 25
     max_levels: int = 2
 
+    pc_saas_api_endpoint: str = False
+    pc_compute_api_endpoint: str = False
+    pc_access_key: str = False
+    pc_secret_key: str = False
+
 
 settings = Settings()
 
@@ -74,7 +79,6 @@ class Environment:
         self.verbose = False
         self.home = os.getcwd()
 
-    # pylint: disable=R0201
     def log(self, msg, *args):
         """Logs a message to stderr"""
         if args:
@@ -273,6 +277,11 @@ def cli_output(data, sort_values=False):
         logging.debug("Error ingesting data into dataframe: %s", _exc)
         sys.exit(1)
 
+    # Before we show the output, remove the index column (which is not data_frame.index),
+    # but only if the column exists.
+    if "index" in data_frame.columns:
+        data_frame.drop(columns=["index"], inplace=True)
+
     # Before we show the output, try to remove duplicate rows
     try:
         # Convert all columns to string
@@ -292,12 +301,14 @@ def cli_output(data, sort_values=False):
 
             # Truncate all cells
             data_frame_truncated = data_frame.applymap(do_truncate, na_action='ignore')
-            table_output = tabulate(data_frame_truncated, headers="keys", tablefmt="table")
+            table_output = tabulate(data_frame_truncated, headers="keys", tablefmt="table", showindex=False)
             click.secho(table_output, fg="green")
         if params["output"] == "json":
+            # Cannot use 'index=False' here, otherwise '.to_json' returns a hash instead of an array of hashes.
+            # But '.to_json' does not output the index anyway.
             click.secho(data_frame.to_json(orient="records"), fg="green")
         if params["output"] == "csv":
-            click.secho(data_frame.to_csv(), fg="green")
+            click.secho(data_frame.to_csv(index=False), fg="green")
         if params["output"] == "html":
             # pre-table-html
             pre_table_html = """
@@ -310,6 +321,7 @@ def cli_output(data, sort_values=False):
             click.secho(pre_table_html)
             click.secho(
                 data_frame.to_html(
+                    index=False,
                     max_cols=settings.max_columns,
                     na_rep='',
                     classes="table table-sm table-striped text-left",
@@ -358,8 +370,8 @@ def flatten_nested_json_df(data_frame):
             level = len(col.split("."))
 
             # Only flatten if level is smaller then settings.max_levels (default: 2) or
-            # ends with tags
-            if level < settings.max_levels or col.endswith("tags"):
+            # contains tags
+            if level < settings.max_levels or "tags" in col:
                 logging.debug("Flatten (list) column: %s (level %s)", col, level)
                 data_frame = data_frame.drop(columns=[col]).join(data_frame[col].explode().to_frame())
                 new_columns.append(col)
